#ifndef _INCLUDED_FILE_RING_H
#define _INCLUDED_FILE_RING_H

#include <Foundation/NSObject.h>

enum FRPosition
{
    PosBeforeCur = 0,
    PosAfterCur,
    PosBegin,
    PosAtEnd
};

@class NSString;
@class NSArray;
@class NSMutableArray;

@interface FileRing : NSObject
{
    NSArray * _allowedTypes;
    NSMutableArray * _files;
    unsigned _pos;
    unsigned _writePos;
}

- (id) init;
- (id) initWithTypes: (NSArray *) allowedTypes;

// Inserts elements from 'paths' into the ring, expanding directories,
// current positio  is set to 0.
- (id) initFromPathArray: (NSArray *)paths withTypes: (NSArray *) allowedTypes;

// Inserts elements from 'paths' into the ring, expanding directories,
// current position is set to first inserted or found element
- (void) insertPathArray: (NSArray *) paths positioning: (int) posMode;

// Inserts 'path' or contents the directory 'path] into the ring,
// current position is set to first inserted or found element.
- (void) insertPath: (NSString *) path positioning: (int) posMode;

- (void) removeAllObjects;

- (NSArray *) allowedTypes;
- (void) setAllowedTypes: (NSArray *) allowedTypes;

- (NSString *) currentPath;
- (NSString *) currentDir;
- (NSString *) currentName;
- (NSString *) nextPath;
- (NSString *) prevPath;


@end // @interface FileRing

#endif // _INCLUDED_FILE_RING_H
