#include "Fragment.h"
#include <AppKit/NSImage.h>
#include <Foundation/NSGeometry.h>

@implementation Fragment


+ (id) fragmentWithScene: (NSRect) scene
{
    return AUTORELEASE([[Fragment alloc] initWithScene: scene]);
}

+ (id) fragmentWithScene: (NSRect) scene
                rotation: (int) degrees
{
    return AUTORELEASE([[Fragment alloc] initWithScene: scene
                                         rotation: degrees]);
}

+ (id) fragmentWithImage: (NSImage *) image
{
    return AUTORELEASE([[Fragment alloc] initWithImage: image]);
}

+ (id) fragmentWithImage: (NSImage *) image
                rotation: (int) degrees
{
    return AUTORELEASE([[Fragment alloc] initWithImage: image
                                         rotation: degrees]);
}

+ (id) fragmentWithFragment: (Fragment *) fragm
{
    return AUTORELEASE([[Fragment alloc] initWithFragment: fragm]);
}

- (id) init
{
    return [self initWithScene: NSZeroRect rotation: 0];
}

- (id) initWithScene: (NSRect) scene
{
    return [self initWithScene: scene rotation: 0];
}

- initWithScene: (NSRect) scene
       rotation: (int) degrees
{
    _scene = scene;
    _orig_rotation = degrees;
    _rotation = _orig_rotation;
    return self;
}

- (id) initWithImage: (NSImage *) image
{
    return [self initWithImage: image
                 rotation: 0];
}

- (id) initWithImage: (NSImage *) image
            rotation: (int) degrees
{
    return [self initWithScene:
                     NSMakeRect(0, 0, [image size].width, [image size].height)
                 rotation: degrees];
}

- (id) initWithFragment: (Fragment *) fragm
{
    // current state in 'fragm' becomes original state in self
    
    return [self initWithScene: [fragm scene]
                 rotation: [fragm rotation]];
}

- (NSRect) scene
{
    return _scene;
}

- (void) setScene: (NSRect) scene
{
    _scene = scene;
}

- (int) span
{
    return MAX( _scene.size.width, _scene.size.height );
}

- (int) rotation
{
    return _rotation;
}

- (void) setRotation: (int) degrees
{
    _rotation = degrees;
}

- (void) rotateByDegrees: (float) degrees
{
    _rotation += degrees;
    _rotation %= 360;
    if (_rotation < 0)
        _rotation += 360;
}

- (id) restoreOriginalState
{
    _rotation = _orig_rotation;
    return self;
}

@end // @implementation Fragment
