#ifndef _INCLUDED_Selection_H
#define _INCLUDED_Selection_H

#include <Foundation/NSObject.h>
#include <Foundation/NSGeometry.h>

@class NSAffineTransform;
@class NSEvent;
@class NSImage;
@class NSCursor;
@class MouseTracker;

@interface Selection : NSObject
{
    NSRect  _fragment;      // In the image coordinates

    NSRect  _sketch;        // In the sketch coordinates

    NSRect _selection;
    NSRect _previousSelection;

    BOOL _is_changing;

    // Transformation fragment -> sketch
    NSAffineTransform   * _xform;

    MouseTracker * _tracker;
}

- (id) init;

- (void) clear;
- (void) setFragment: (NSRect) fragment xform: (NSAffineTransform *) xform;

// 'pt' is in sketch coordinates
- (void) mouseDown: (NSPoint) pt;
- (void) mouseDragged: (NSPoint) pt;
- (void) mouseUp: (NSPoint) pt;

// Returns an array of CursorRectInfo's
- (NSArray *) cursorRects;

- (NSCursor *) trackingCursor;

// Returns YES if selection is non-empty
- (BOOL) valid;

// Return YES if user is currently editing the selection (mouse button pressed)
- (BOOL) isChanging;

// Sketch coordinates
- (NSRect) selectedInSketch;

// Sketch coordinates
- (NSRect) updateInSketch;

// Image coordinates
- (NSRect) selectedInImage;

// Returns YES if the point is outside of the outer boundary of the sel. egde
- (BOOL) isOutOfSelPoint: (NSPoint) pt;

- (NSImage *) mask;

// 'rect' is in sketch coordinates
- (NSImage *) maskForRect: (NSRect) rect;


@end // interface Selection

#endif // _INCLUDED_Selection_H
